==> cpes6-project-1.1.1.tgz: package/src/css.js <==
/**
 * Created with WebStorm.
 * @author: jozhua@live.cn
 * @date: 2017/9/19
 * To change this template use File | Settings | File Templates.
 */
import './stylesheets';
import cp from './els';
const cssNumber = {
    'font-weight': 1,
    'line-height': 1,
    'opacity': 1,
    'z-index': 1,
    'zoom': 1
};
function camelize(str) {
    return str.replace(/-+(.)?/g, function (match, chr) {
        return chr ? chr.toUpperCase() : ''
    })
}
function dasherize(str) {
    return str.replace(/::/g, '/')
        .replace(/([A-Z]+)([A-Z][a-z])/g, '$1_$2')
        .replace(/([a-z\d])([A-Z])/g, '$1_$2')
        .replace(/_/g, '-')
        .toLowerCase()
}

function maybeAddPx(name, value) {
    return (typeof value == "number" && !cssNumber[dasherize(name)]) ? value + "px" : value
}

cp.fn.css = function (property, value) {
    if (arguments.length < 2) {
        var element = this[0], computedStyle = cp.getCurrentStyle(element)
        if (!element) return
        if (typeof property == 'string') return element.style[camelize(property)] || computedStyle.getPropertyValue(property)
        else if (cp.isArray(property)) {
            var props = {}
            cp.each(property, function (_, prop) {
                props[prop] = (element.style[camelize(prop)] || computedStyle.getPropertyValue(prop))
            });
            return props
        }
    }
    var css = '', key;
    if (type(property) == 'string') {
        if (!value && value !== 0)
            this.each(function () {
                this.style.removeProperty(dasherize(property))
            })
        else css = dasherize(property) + ":" + maybeAddPx(property, value)
    } else {
        for (key in property)
            if (!property[key] && property[key] !== 0)
                this.each(function () {
                    this.style.removeProperty(dasherize(key))
                })
            else css += dasherize(key) + ':' + maybeAddPx(key, property[key]) + ';'
    }
    return this.each(function () {
        this.style.cssText += ';' + css
    })
}

==> cpes6-project-1.1.8.tgz: package/src/css.js <==
/**
 * Created with WebStorm.
 * @author: jozhua@live.cn
 * @date: 2017/9/19
 * To change this template use File | Settings | File Templates.
 */
import './stylesheets';
import cp from './els';
const cssNumber = {
    'font-weight': 1,
    'line-height': 1,
    'opacity': 1,
    'z-index': 1,
    'zoom': 1
};
function camelize(str) {
    return str.replace(/-+(.)?/g, function (match, chr) {
        return chr ? chr.toUpperCase() : ''
    })
}
function dasherize(str) {
    return str.replace(/::/g, '/')
        .replace(/([A-Z]+)([A-Z][a-z])/g, '$1_$2')
        .replace(/([a-z\d])([A-Z])/g, '$1_$2')
        .replace(/_/g, '-')
        .toLowerCase()
}

function maybeAddPx(name, value) {
    return (typeof value == "number" && !cssNumber[dasherize(name)]) ? value + "px" : value
}

cp.fn.css = function (property, value) {
    if (arguments.length < 2) {
        var element = this[0], computedStyle = cp.getCurrentStyle(element)
        if (!element) return
        if (typeof property == 'string') return element.style[camelize(property)] || computedStyle.getPropertyValue(property)
        else if (cp.isArray(property)) {
            var props = {}
            cp.each(property, function (_, prop) {
                props[prop] = (element.style[camelize(prop)] || computedStyle.getPropertyValue(prop))
            });
            return props
        }
    }
    var css = '', key;
    if (typeof property == 'string') {
        if (!value && value !== 0)
            this.each(function () {
                this.style.removeProperty(dasherize(property))
            })
        else css = dasherize(property) + ":" + maybeAddPx(property, value)
    } else {
        for (key in property)
            if (!property[key] && property[key] !== 0)
                this.each(function () {
                    this.style.removeProperty(dasherize(key))
                })
            else css += dasherize(key) + ':' + maybeAddPx(key, property[key]) + ';'
    }
    return this.each(function () {
        this.style.cssText += ';' + css
    })
}
